<?php

/**
 * Register maskitto options
 */

if (!class_exists('maskitto_light_Redux_Framework_config')) {

    class maskitto_light_Redux_Framework_config {

        public $args        = array();
        public $sections    = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {

            if (!class_exists('ReduxFramework')) {
                return;
            }

            // This is needed. Bah WordPress bugs.  ;)
            if ( true == Redux_Helpers::isTheme( __FILE__ ) ) {
                $this->initSettings();
            } else {
                add_action('plugins_loaded', array($this, 'initSettings'), 10);
            }

        }

        public function initSettings() {

            // Just for demo purposes. Not needed per say.
            $this->theme = wp_get_theme();

            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if (!isset($this->args['opt_name'])) { // No errors please
                return;
            }

            // If Redux is running as a plugin, this will remove the demo notice and links
            add_action( 'redux/loaded', array( $this, 'remove_demo' ) );
            
            // Function to test the compiler hook and demo CSS output.
            // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
            //add_filter('redux/options/'.$this->args['opt_name'].'/compiler', array( $this, 'compiler_action' ), 10, 2);
            
            // Change the arguments after they've been declared, but before the panel is created
            //add_filter('redux/options/'.$this->args['opt_name'].'/args', array( $this, 'change_arguments' ) );
            
            // Change the default value of a field after it's been set, but before it's been useds
            //add_filter('redux/options/'.$this->args['opt_name'].'/defaults', array( $this,'change_defaults' ) );
            
            // Dynamically add a section. Can be also used to modify sections/fields
            //add_filter('redux/options/' . $this->args['opt_name'] . '/sections', array($this, 'dynamic_section'));

            $this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
        }

        /**

          This is a test function that will let you see when the compiler hook occurs.
          It only runs if a field	set with compiler=>true is changed.

         * */
        function compiler_action($options, $css) {
            //echo '<h1>The compiler hook has run!';
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )

            /*
              // Demo of how to use the dynamic CSS and write your own static CSS file
              $filename = dirname(__FILE__) . '/style' . '.css';
              global $wp_filesystem;
              if( empty( $wp_filesystem ) ) {
                require_once( ABSPATH .'/wp-admin/includes/file.php' );
              WP_Filesystem();
              }

              if( $wp_filesystem ) {
                $wp_filesystem->put_contents(
                    $filename,
                    $css,
                    FS_CHMOD_FILE // predefined mode settings for WP files
                );
              }
             */
        }

        /**

          Custom function for filtering the sections array. Good for child themes to override or add to the sections.
          Simply include this function in the child themes functions.php file.

          NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
          so you must use get_template_directory_uri() if you want to use any of the built in icons

         * */
        function dynamic_section($sections) {
            //$sections = array();
            $sections[] = array(
                'title' => __('Section via hook', 'maskitto-light'),
                'desc' => __('<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'maskitto-light'),
                'icon' => 'el-icon-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }

        /**

          Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.

         * */
        function change_arguments($args) {
            //$args['dev_mode'] = true;

            return $args;
        }

        /**

          Filter hook for filtering the default value of any given field. Very useful in development mode.

         * */
        function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        function remove_demo() {

            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                remove_filter('plugin_row_meta', array(ReduxFrameworkPlugin::instance(), 'plugin_metalinks'), null, 2);

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {

            /**
              Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
             * */
            // Background Patterns Reader
            $sample_patterns_path   = ReduxFramework::$_dir . '../sample/patterns/';
            $sample_patterns_url    = ReduxFramework::$_url . '../sample/patterns/';
            $sample_patterns        = array();

            if (is_dir($sample_patterns_path)) :

                if ($sample_patterns_dir = opendir($sample_patterns_path)) :
                    $sample_patterns = array();

                    while (( $sample_patterns_file = readdir($sample_patterns_dir) ) !== false) {

                        if (stristr($sample_patterns_file, '.png') !== false || stristr($sample_patterns_file, '.jpg') !== false) {
                            $name = explode('.', $sample_patterns_file);
                            $name = str_replace('.' . end($name), '', $sample_patterns_file);
                            $sample_patterns[]  = array('alt' => $name, 'img' => $sample_patterns_url . $sample_patterns_file);
                        }
                    }
                endif;
            endif;

            ob_start();

            $ct             = wp_get_theme();
            $this->theme    = $ct;
            $item_name      = $this->theme->get('Name');
            $tags           = $this->theme->Tags;
            $screenshot     = $this->theme->get_screenshot();
            $class          = $screenshot ? 'has-screenshot' : '';

            $customize_title = sprintf(__('Customize &#8220;%s&#8221;', 'maskitto-light'), $this->theme->display('Name'));
            
            ?>
            <div id="current-theme" class="<?php echo esc_attr($class); ?>">
            <?php if ($screenshot) : ?>
                <?php if (current_user_can('edit_theme_options')) : ?>
                        <a href="<?php echo wp_customize_url(); ?>" class="load-customize hide-if-no-customize" title="<?php echo esc_attr($customize_title); ?>">
                            <img src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e( 'Current theme preview', 'maskitto-light' ); ?>" />
                        </a>
                <?php endif; ?>
                    <img class="hide-if-customize" src="<?php echo esc_url($screenshot); ?>" alt="<?php esc_attr_e( 'Current theme preview', 'maskitto-light' ); ?>" />
                <?php endif; ?>

                <h4><?php echo $this->theme->display('Name'); ?></h4>

                <div>
                    <ul class="theme-info">
                        <li><?php printf(__('By %s', 'maskitto-light'), $this->theme->display('Author')); ?></li>
                        <li><?php printf(__('Version %s', 'maskitto-light'), $this->theme->display('Version')); ?></li>
                        <li><?php echo '<strong>' . __('Tags', 'maskitto-light') . ':</strong> '; ?><?php printf($this->theme->display('Tags')); ?></li>
                    </ul>
                    <p class="theme-description"><?php echo $this->theme->display('Description'); ?></p>
            <?php
            if ($this->theme->parent()) {
                printf(' <p class="howto">' . __( 'This <a href="%1$s">child theme</a> requires its parent theme, %2$s.', 'maskitto-light') . '</p>', __('http://codex.wordpress.org/Child_Themes', 'maskitto-light'), $this->theme->parent()->display('Name'));
            }
            ?>

                </div>
            </div>

            <?php
            $item_info = ob_get_contents();

            ob_end_clean();

            $sampleHTML = '';
            if (file_exists(dirname(__FILE__) . '/info-html.html')) {
                /** @global WP_Filesystem_Direct $wp_filesystem  */
                global $wp_filesystem;
                if (empty($wp_filesystem)) {
                    require_once ABSPATH . '/wp-admin/includes/file.php';
                    WP_Filesystem();
                }
                $sampleHTML = $wp_filesystem->get_contents(dirname(__FILE__) . '/info-html.html');
            }


            // ACTUAL DECLARATION OF SECTIONS
            $this->sections[] = array(
                'icon'      => 'el-icon-cog',
                'title'     => __('General', 'maskitto-light'),
                'fields'    => array(

                    array(
                        'id'       => 'page-layout',
                        'type'     => 'radio',
                        'title'    => __('Page Layout', 'maskitto-light'), 
                        'subtitle' => __('Choose page layout type', 'maskitt-light'),
                        'options'  => array(
                            '1' => 'Standard', 
                            '2' => 'Boxed', 
                            '3' => 'Full'
                        ),
                        'default' => '1'
                    ),

                    array(
                        'id'        => 'responsive-status',
                        'type'      => 'switch',
                        'title'     => __('Responsive', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable responsive design to make web site more static', 'maskitto-light'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'minity-status',
                        'type'      => 'switch',
                        'title'     => __('Minify', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable compresed file version use', 'maskitto-light'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'logo-image',
                        'type'      => 'media',
                        'url'       => true,
                        'title'     => __('Logo', 'maskitto-light'),
                        'compiler'  => 'true',
                        'subtitle'  => __('Upload your web site logo', 'maskitto-light'),
                        'default'   => array('url' => get_header_image() ),
                    ),

                    array(
                        'id'        => 'favicon-image',
                        'type'      => 'media',
                        'url'       => true,
                        'title'     => __('Favicon', 'maskitto-light'),
                        'compiler'  => 'true',
                        'subtitle'  => __('Upload your web site favicon, recomended 32x32', 'maskitto-light'),
                    ),

                    array(
                        'id'        => 'back-to-top',
                        'type'      => 'switch',
                        'title'     => __('Back to top', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable "back to top" button', 'maskitto-light'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'footer-text',
                        'type'      => 'editor',
                        'title'     => __('Footer Text', 'maskitto-light'),
                        'subtitle'  => __('Add additional information in footer', 'maskitto-light'),
                        'default'   => '',
                    ),

                    $fields = array(
                        'id'       => 'custom-css',
                        'type'     => 'ace_editor',
                        'title'    => __('CSS Code', 'maskitto-light'),
                        'subtitle' => __('You can add you custom CSS code here', 'maskitto-light'),
                        'mode'     => 'css',
                        'theme'    => 'monokai',
                        'default'  => "#some-block{\npadding: 0;\n}"
                    )
                )
            );


            $this->sections[] = array(
                'icon'      => 'el-icon-fontsize',
                'title'     => __('Styling', 'maskitto-light'),
                'fields'    => array(

                    array(
                        'id'        => 'primary-color',
                        'type'      => 'color',
                        'title'     => __('Accent Color', 'maskitto-light'),
                        'subtitle'  => __('Define main accent color', 'maskitto-light'),
                        'default'   => '#e15454',
                        'validate'  => 'color',
                        'transparent' => false
                    ),

                    array(
                        'id'        => 'body-background-color',
                        'type'      => 'color',
                        'title'     => __('Body Background Color', 'maskitto-light'),
                        'subtitle'  => __('Change default background color', 'maskitto-light'),
                        'default'   => '#ffffff',
                        'validate'  => 'color',
                        'transparent' => false
                    ),

                    array(
                        'id'        => 'footer-background-color',
                        'type'      => 'color',
                        'title'     => __('Footer Background color', 'maskitto-light'),
                        'subtitle'  => __('Change default footer background color', 'maskitto-light'),
                        'default'   => '#3C3C3C',
                        'validate'  => 'color',
                        'transparent' => false
                    ),

                    array(
                        'id'        => 'blog-background',
                        'type'      => 'background',
                        'title'     => __('Blog Background', 'maskitto-light'),
                        'subtitle'  => __('Change default blog backgrund image and color', 'maskitto-light'),
                        'default'   => array(
                            'background-color' => '#f2f4f5',
                            'background-image' => get_template_directory_uri().'/img/blogbg.png'
                        ),
                        'transparent' => false,
                        'background-repeat' => false,
                        'background-size' => false,
                        'background-attachment' => false,
                        'background-position' => false,
                    ),

                    array(
                        'id'        => 'body-font',
                        'type'      => 'typography',
                        'title'     => __('Body Font', 'maskitto-light'),
                        'subtitle'  => __('Change default web site font', 'maskitto-light'),
                        'google'    => false,
                        'compiler' => false,
                        'default'   => array(
                            'color'         => '#565656',
                            'font-size'     => '13px',
                            'font-family'   => 'Open Sans',
                            'font-weight'   => 'Normal',
                        ),
                        'line-height' => false,
                        'text-align' => false,
                        'font-size' => false,
                        'font-style' => false,
                        'font-weight' => false,
                    ),

                )
            );


            $this->sections[] = array(
                'icon'      => 'el-icon-th',
                'title'     => __('Header', 'maskitto-light'),
                'fields'    => array(

                    array(
                        'id'       => 'header-layout',
                        'type'     => 'radio',
                        'title'    => __('Header Layout', 'maskitto-light'), 
                        'subtitle' => __('Choose header layout type', 'maskitt-light'),
                        'options'  => array(
                            '1' => 'Standard (for wider logo)', 
                            '2' => 'Centered (for square-like large logo)', 
                            '3' => 'Centered (for square-like small logo)',
                            '4' => 'Inverted (logo in right side and menu in left)',
                        ),
                        'default' => '1'
                    ),

                    array(
                        'id'       => 'nacigation-dropdown',
                        'type'     => 'radio',
                        'title'    => __('Navigation dropdown', 'maskitto-light'), 
                        'subtitle' => __('Choose navigation dropdown action', 'maskitt-light'),
                        'options'  => array(
                            '1' => 'On click', 
                            '2' => 'On hover (without parent URL)', 
                        ),
                        'default' => '1'
                    ),

                    array(
                        'id'        => 'header-contacts',
                        'type'      => 'switch',
                        'title'     => __('Contact  information', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable contact information from header', 'maskitto-light'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'header-social',
                        'type'      => 'switch',
                        'title'     => __('Social icons', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable hide contact social icons from header', 'maskitto-light'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'header-social-links',
                        'type'      => 'switch',
                        'title'     => __('Open social links in new tab', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable option for open social icon links in new tab', 'maskitto-light'),
                        'default'   => true,
                    ),

                    array(
                        'id'        => 'header-contacts-mail',
                        'type'      => 'text',
                        'title'     => __('Contact mail', 'maskitto-light'),
                        'subtitle'  => __('Your website email adress', 'maskitto-light'),
                        'validate'  => 'email',
                        'default'   => 'info@mywebsite.com',
                    ),

                    array(
                        'id'        => 'header-contacts-phone',
                        'type'      => 'text',
                        'title'     => __('Contact phone', 'maskitto-light'),
                        'subtitle'  => __('Your website phone number', 'maskitto-light'),
                        'msg'       => 'custom error message',
                        'default'   => '800-2312-323',
                    ),

                )
            );


            $this->sections[] = array(
                'icon'      => 'el-icon-twitter',
                'title'     => __('Social', 'maskitto-light'),
                'fields'    => array(

                    array(
                        'id'        => 'social-network-twitter',
                        'type'      => 'text',
                        'title'     => __('Twitter', 'maskitto-light'),
                        'subtitle'  => __('Your Twitter URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'default'   => 'http://www.twitter.com/TheShufflehound',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-facebook',
                        'type'      => 'text',
                        'title'     => __('Facebook', 'maskitto-light'),
                        'subtitle'  => __('Your Facebook page/profile URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-google',
                        'type'      => 'text',
                        'title'     => __('Google+', 'maskitto-light'),
                        'subtitle'  => __('Your Google+ URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-youtube',
                        'type'      => 'text',
                        'title'     => __('Yotube', 'maskitto-light'),
                        'subtitle'  => __('Your Yotube URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-instagram',
                        'type'      => 'text',
                        'title'     => __('Instagram', 'maskitto-light'),
                        'subtitle'  => __('Your Instagram URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-flickr',
                        'type'      => 'text',
                        'title'     => __('Flickr', 'maskitto-light'),
                        'subtitle'  => __('Your Flickr URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-foursquare',
                        'type'      => 'text',
                        'title'     => __('Foursquare', 'maskitto-light'),
                        'subtitle'  => __('Your Foursquare URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-skype',
                        'type'      => 'text',
                        'title'     => __('Skype', 'maskitto-light'),
                        'subtitle'  => __('Your skype profile URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-vk',
                        'type'      => 'text',
                        'title'     => __('VK', 'maskitto-light'),
                        'subtitle'  => __('Your VK profile URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-wordpress',
                        'type'      => 'text',
                        'title'     => __('Wordpress', 'maskitto-light'),
                        'subtitle'  => __('Your Wordpress profile URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'default'   => 'https://wordpress.org/themes/maskitto-light',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-linkedin',
                        'type'      => 'text',
                        'title'     => __('Linkedin', 'maskitto-light'),
                        'subtitle'  => __('Your Linked profile URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),

                    array(
                        'id'        => 'social-network-pinterest',
                        'type'      => 'text',
                        'title'     => __('Pinterest', 'maskitto-light'),
                        'subtitle'  => __('Your Pinterest profile URL', 'maskitto-light'),
                        'validate'  => 'url',
                        'text_hint' => array(
                            'title'     => '',
                            'content'   => 'Please enter a valid <strong>URL</strong> in this field.'
                        )
                    ),


                )
            );


            $this->sections[] = array(
                'icon'      => 'el-icon-th',
                'title'     => __('Blog', 'maskitto-light'),
                'fields'    => array(

                    array(
                        'id'       => 'blog-layout',
                        'type'     => 'radio',
                        'title'    => __('Blog Layout', 'maskitto-light'), 
                        'subtitle' => __('Choose blog layout type', 'maskitt-light'),
                        'options'  => array(
                            '1' => 'Standard', 
                            '2' => 'Old', 
                        ),
                        'default' => '1'
                    ),

                    array(
                        'id'        => 'blog-thumb-status',
                        'type'      => 'switch',
                        'title'     => __('Blog title image', 'maskitto-light'),
                        'subtitle'  => __('Enable or disable large title image and description at the top of blog page', 'maskitto-light'),
                        'default'   => true,
                    ),

                   array(
                        'id'        => 'blog-thumb-url',
                        'type'      => 'media',
                        'url'       => true,
                        'title'     => __('Blog title url', 'maskitto-light'),
                        'compiler'  => 'true',
                        'subtitle'  => __('Upload image', 'maskitto-light'),
                        'default'   => array('url' => get_template_directory_uri().'/img/bloghead.jpg'),
                    ),

                    array(
                        'id'        => 'blog-thumb-title',
                        'type'      => 'text',
                        'title'     => __('Blog title', 'maskitto-light'),
                        'subtitle'  => __('Enter title', 'maskitto-light'),
                        'default'   => 'A brief revision of my vision',
                    ),

                )
            );


            $this->sections[] = array(
                'icon'      => 'el-icon-lock',
                'title'     => __('Admin', 'maskitto-light'),
                'fields'    => array(

                    array(
                        'id'        => 'admin-login-logo',
                        'type'      => 'media',
                        'url'       =>  true,
                        'title'     => __('Login page logo', 'maskitto-light'),
                        'subtitle'  => __('Upload your web site logo to change login page look', 'maskitto-light'),
                    ),

                )
            );



            $this->sections[] = array(
                'title'     => __('Import / Export', 'maskitto-light'),
                'desc'      => __('Import and Export your Redux Framework settings from file, text or URL.', 'maskitto-light'),
                'icon'      => 'el-icon-refresh',
                'fields'    => array(
                    array(
                        'id'            => 'opt-import-export',
                        'type'          => 'import_export',
                        'title'         => 'Import Export',
                        'subtitle'      => 'Save and restore your Redux options',
                        'full_width'    => false,
                    ),
                ),
            );


            $theme_info  = '<div class="redux-framework-section-desc">';
            $theme_info .= '<p class="redux-framework-theme-data description theme-uri">' . __('<strong>Theme URL:</strong> ', 'maskitto-light') . '<a href="' . $this->theme->get('ThemeURI') . '" target="_blank">' . $this->theme->get('ThemeURI') . '</a></p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-author">' . __('<strong>Author:</strong> ', 'maskitto-light') . $this->theme->get('Author') . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-version">' . __('<strong>Version:</strong> ', 'maskitto-light') . $this->theme->get('Version') . '</p>';
            $theme_info .= '<p class="redux-framework-theme-data description theme-description">' . $this->theme->get('Description') . '</p>';
            $tabs = $this->theme->get('Tags');
            if (!empty($tabs)) {
                $theme_info .= '<p class="redux-framework-theme-data description theme-tags">' . __('<strong>Tags:</strong> ', 'maskitto-light') . implode(', ', $tabs) . '</p>';
            }
            $theme_info .= '</div>';


        }

        public function setHelpTabs() {

            // Custom page help tabs, displayed using the help API. Tabs are shown in order of definition.
            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-1',
                'title'     => __('Theme Information 1', 'maskitto-light'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'maskitto-light')
            );

            $this->args['help_tabs'][] = array(
                'id'        => 'redux-help-tab-2',
                'title'     => __('Theme Information 2', 'maskitto-light'),
                'content'   => __('<p>This is the tab content, HTML is allowed.</p>', 'maskitto-light')
            );

            // Set the help sidebar
            $this->args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'maskitto-light');
        }

        /**

          All the possible arguments for Redux.
          For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments

         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                'opt_name' => 'maskitto_light',
                'page_slug' => 'maskitto_options',
                'page_title' => 'Maskitto Options',
                'update_notice' => true,
                'admin_bar' => true,
                'menu_type' => 'menu',
                'menu_title' => 'Maskitto Light Options',
                'allow_sub_menu' => true,
                'page_parent_post_type' => 'your_post_type',
                'customizer' => true,
                'dev_mode' => false,
                'hints' => 
                array(
                  'icon' => 'el-icon-question-sign',
                  'icon_position' => 'right',
                  'icon_size' => 'normal',
                  'tip_style' => 
                  array(
                    'color' => 'light',
                  ),
                  'tip_position' => 
                  array(
                    'my' => 'top left',
                    'at' => 'bottom right',
                  ),
                  'tip_effect' => 
                  array(
                    'show' => 
                    array(
                      'duration' => '500',
                      'event' => 'mouseover',
                    ),
                    'hide' => 
                    array(
                      'duration' => '500',
                      'event' => 'mouseleave unfocus',
                    ),
                  ),
                ),
                'output' => true,
                'output_tag' => true, /* output!! = true */
                'compiler' => true,
                'page_icon' => 'icon-themes',
                'page_permissions' => 'manage_options',
                'save_defaults' => true,
                'show_import_export' => true,
                'transient_time' => '3600',
                'network_sites' => true,
              );

            $theme = wp_get_theme(); // For use with some settings. Not necessary.
            $this->args["display_name"] = $theme->get("Name");
            $this->args["display_version"] = $theme->get("Version");

            // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            /*$this->args['share_icons'][] = array(
                'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
                'title' => 'Visit us on GitHub',
                'icon'  => 'el-icon-github'
                //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
            );*/
            /*$this->args['share_icons'][] = array(
                'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
                'title' => 'Like us on Facebook',
                'icon'  => 'el-icon-facebook'
            );*/
            $this->args['share_icons'][] = array(
                'url'   => 'http://twitter.com/TheShufflehound',
                'title' => 'Follow us on Twitter',
                'icon'  => 'el-icon-twitter'
            );
           /* $this->args['share_icons'][] = array(
                'url'   => 'http://www.linkedin.com/company/redux-framework',
                'title' => 'Find us on LinkedIn',
                'icon'  => 'el-icon-linkedin'
            );*/

        }

    }
    
    global $reduxConfig;
    $reduxConfig = new maskitto_light_Redux_Framework_config();
}

/**
  Custom function for the callback referenced above
 */
if (!function_exists('maskitto_light_my_custom_field')):
    function maskitto_light_my_custom_field($field, $value) {
        print_r($field);
        echo '<br/>';
        print_r($value);
    }
endif;

/**
  Custom function for the callback validation referenced above
 * */
if (!function_exists('maskitto_light_validate_callback_function')):
    function maskitto_light_validate_callback_function($field, $value, $existing_value) {
        $error = false;
        $value = 'just testing';

        $return['value'] = $value;
        if ($error == true) {
            $return['error'] = $field;
        }
        return $return;
    }
endif;